---
name: Bug report
about: Report a bug in the library
title: "[BUG] <replace me>"
labels: bug
assignees: EEKIM10

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behaviour, preferably with some code to go with it. Not all of your source code, just what's required to reproduce the bug.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Tracebacks (if applicable)**
If you have very large tracebacks, consider using a paste service, such as [gist.github.com](https://gist.github.com) or [MystBin](https://mystb.in)

**Additional context**
Add any other context about the problem here. Such could be examples of the intended behaviour, links to source code where the error may be, etc.
